/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "WebKitTransitionEvent.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomEvent.h"
#include "gdom/GdomWebKitTransitionEvent.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomEvent.h"
#include "gdom/PrivateGdomWebKitTransitionEvent.h"
#include "gdom/PrivateIntGdomWebKitTransitionEvent.h"
#include "glib-object.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMWebKitTransitionEvent::GDOMWebKitTransitionEvent(PassRefPtr<WebCore::WebKitTransitionEvent> impl)
    : GDOMEvent(impl)
{
}

void
gdom_web_kit_transition_event_init_web_kit_transition_event (GdomWebKitTransitionEvent *thiz, gchar * type_arg, gboolean can_bubble_arg, gboolean cancelable_arg, gchar * property_name_arg, gdouble elapsed_time_arg)
{
    g_return_if_fail (thiz);
    WebCore::WebKitTransitionEvent * item = (gdom_web_kit_transition_event_get_private(thiz));
    g_return_if_fail (item);
    g_return_if_fail (type_arg);
    g_return_if_fail (property_name_arg);
    WebCore::String _g_type_arg = WebCore::String::fromUTF8(type_arg);
    WebCore::String _g_property_name_arg = WebCore::String::fromUTF8(property_name_arg);
    item->initWebKitTransitionEvent(_g_type_arg, can_bubble_arg, cancelable_arg, _g_property_name_arg, elapsed_time_arg);

}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "WebKitTransitionEvent.h"
#include <gdom/GdomWebKitTransitionEvent.h>
#include <gdom/PrivateGdomWebKitTransitionEvent.h>
#include <gdom/PrivateIntGdomWebKitTransitionEvent.h>
#include <gdom/GdomWebKitTransitionEventprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomWebKitTransitionEvent, gdom_web_kit_transition_event, GDOM_TYPE_EVENT);

/*
struct _GdomWebKitTransitionEventPrivate {
    class WebCore::WebKitTransitionEvent *item;
};

#define GDOM_WEB_KIT_TRANSITION_EVENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_WEB_KIT_TRANSITION_EVENT, GdomWebKitTransitionEventPrivate))
*/
G_END_DECLS
WebCore::WebKitTransitionEvent *
gdom_web_kit_transition_event_get_private(GdomWebKitTransitionEvent *request)
{
    GDOMWebKitTransitionEvent *res;
    res = static_cast<GDOMWebKitTransitionEvent*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::WebKitTransitionEvent*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_PROPERTY_NAME,
    PROP_ELAPSED_TIME,
};


static void gdom_web_kit_transition_event_finalize(GObject* object)
{
    /*GdomWebKitTransitionEvent* request = GDOM_WEB_KIT_TRANSITION_EVENT(object);*/
    /*GdomWebKitTransitionEventPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_EVENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_web_kit_transition_event_parent_class)->finalize(object);
}

static void gdom_web_kit_transition_event__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomWebKitTransitionEvent *self = GDOM_WEB_KIT_TRANSITION_EVENT(object);
    WebCore::WebKitTransitionEvent * gself = (gdom_web_kit_transition_event_get_private(self));
    switch (prop_id) {
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_web_kit_transition_event__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomWebKitTransitionEvent *self = GDOM_WEB_KIT_TRANSITION_EVENT(object);
    WebCore::WebKitTransitionEvent * gself = (gdom_web_kit_transition_event_get_private(self));
    switch (prop_id) {
    case PROP_PROPERTY_NAME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->propertyName()));
         break;
    }
    case PROP_ELAPSED_TIME:
    {
         g_value_set_double (value, gself->elapsedTime());
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_web_kit_transition_event_class_init(GdomWebKitTransitionEventClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_web_kit_transition_event_finalize;
    g_klass->set_property = gdom_web_kit_transition_event__set_property_fn;
    g_klass->get_property = gdom_web_kit_transition_event__get_property_fn;

    g_object_class_install_property (g_klass, PROP_PROPERTY_NAME,
            g_param_spec_string ("property_name", /* name */
                "web_kit_transition_event_property_name", /* short description */
                "read-only  gchar * WebKitTransitionEvent.property_name", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READABLE));

     g_object_class_install_property (g_klass, PROP_ELAPSED_TIME,
            g_param_spec_double ("elapsed_time", /* name */
                "web_kit_transition_event_elapsed_time", /* short description */
                "read-only  gdouble WebKitTransitionEvent.elapsed_time", /* longer - could do with some extra doc stuff here */
                 G_MINDOUBLE,        /* min */
                G_MAXDOUBLE, /* max */
                0,        /* default */
                 (GParamFlags)G_PARAM_READABLE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomWebKitTransitionEventPrivate));*/
}

static void gdom_web_kit_transition_event_init(GdomWebKitTransitionEvent* request)
{
    /*GdomWebKitTransitionEventPrivate* priv = GDOM_WEB_KIT_TRANSITION_EVENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

